Re: String freeze break requested for Orca for GNOME 2.17.92



Hi All:

Attached is a patch for the ngettext change as requested in response to the original request. In discussing this issue with Andre Klapper on IRC, we agreed the move forward plan is this:

1) Limit the break request to nautilus.py.  The feature supported by it
comes at the request of our users and they really want to see it get in
for GNOME 2.18.

2) Postpone the Gecko.py changes to GNOME 2.19. My feeling is that there are too many strings to mark as translatable and I'd rather not put undo burden on the l10n team for GNOME 2.18.

All we need is one thumbs up on this. :-) If there is sufficient pushback, however, we will pull the specialized nautilus support from GNOME 2.18 and wait until GNOME 2.19. But...we just need to know one way or the other.

Thanks!

Will

Willie Walker wrote:
OK, after some arm twisting, I've been convinced to unretract this request. So, I'm re-requesting it with the following amendment: we will fix the ngettext issue with the " % items" string for nautilus.py.

The nautilus.py fix is the result of a user request, and is discussed laboriously here: http://bugzilla.gnome.org/show_bug.cgi?id=350674. We'd really like to get this fix in for GNOME 2.18 as it addresses a usability issue.

The Gecko.py fix is just due to stupidity on my part for not marking the strings as translatable to begin with.

Are these things we can get in for GNOME 2.18?

Will

Willie Walker wrote:
Hi All:

Due to various midair collisions, I'm getting the feeling that the timing of this is all bad. We'll wait until GNOME 2.19.x.

Thanks,

Will

Willie Walker wrote:
Hi All:

I'm requesting a string freeze break for Orca.  The first one, which
is in src/orca/nautilus.py comes as a result of a direct request from
our user community.  It helps users understand how many items they are
working with in a folder when they open it in nautilus.  It is a
highly desired feature by our users.

src/orca/scripts/nautilus.py:

                        itemCountString = _(" %d items") % itemCount

The second is the result of me (my fault) forgetting to mark strings
as needing translation in our Gecko.py script for Firefox and
Thunderbird.  I apologize greatly for this, as I'm usually the
anal-retentive internationalization guy on the team.  :-(

src/orca/Gecko.py:

                _("Dumps document content to stdout."))
                _("Goes to next character."))
                _("Goes to previous character."))
                _("Goes to next word."))
                _("Goes to previous word."))
                _("Goes to next line."))
                _("Goes to previous line."))
                _("Goes to previous heading."))
                _("Goes to next heading."))
                _("Goes to previous chunk."))
                _("Goes to next chunk."))
                _("Switches between Gecko and Orca caret navigation."))
            string = _("Gecko is controlling the caret.")
            string = _("Orca is controlling the caret.")

Please let me know if this is OK.

Will





Index: src/orca/scripts/nautilus.py
===================================================================
--- src/orca/scripts/nautilus.py	(revision 2042)
+++ src/orca/scripts/nautilus.py	(working copy)
@@ -33,7 +33,8 @@
 import orca.speech as speech
 import orca.util as util
 
-from orca.orca_i18n import _ # for gettext support
+from orca.orca_i18n import _        # for gettext support
+from orca.orca_i18n import ngettext # for ngettext support
 
 ########################################################################
 #                                                                      #
@@ -100,7 +101,9 @@
                     elif child.role == rolenames.ROLE_TABLE:
                         itemCount = child.table.nRows
                     if itemCount != -1:
-                        itemCountString = " %d items" % itemCount
+                        itemCountString = ngettext(" %d item",
+                                                   " %d items",
+                                                   itemCount) % itemCount
                     break
 
         return itemCountString


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]